@@ -10,7 +10,7 @@ namespace py = pybind11;
 using namespace std;
 
 
-PYBIND11_MODULE(dank, m) {
+PYBIND11_MODULE(_dank, m) {
     py::class_<DFA>(m, "DFA")
         .def(py::init())
         .def("from_regex", &DFA::from_regex)
